Learn R Programming

diversityArch (version 0.1.0)

Qesem_f: Data used in the examples

Description

Data frame with number of fragments of bones of unidentified spicies but identified group for several levels in Qesem (Israel). Data source: Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A., (2024)

Usage

data(Qesem_f)

Arguments

Value

Data frame with 4 observations (groups) and 7 levels.

Author

Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A.

References

Barat, A. Sansó, A. Arilla-Osuna, M. Blasco, R., Pérez-Fernández, I., Cifuentes-Alcobenda, G. Llorente, R., Vivar-Ríos, D., Assaf, E. Barkai, R., Gopher, A. & Rosell-Ardèvol, J., 2025. Quantifying Diversity through Entropy Decomposition. Insights into Hominin Occupation and Carcass Processing at Qesem cave. Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A., 2024. Exploring the lack of articular ends at the Middle Pleistocene site of Qesem Cave, Israel. Journal of Human Evolution 189, 103509. doi:10.1016/j.jhevol.2024.103509

Examples

Run this code
data(Qesem_f)
names(data)
# The following example replicates some of the results of Table 5 in
# Barat, A. Sansó, A. Arilla-Osuna, M. Blasco, R., Pérez-Fernández, I.,
# Cifuentes-Alcobenda, G. Llorente, R., Vivar-Ríos, D., Assaf, E. Barkai, R.,
# Gopher, A. & Rosell-Ardèvol, J., 2025. "Quantifying Diversity through Entropy
# Decomposition. Insights into Hominin Occupation and Carcass Processing at Qesem cave".
shannon_frag(Qesem_s$HU, Qesem_s$Group, Qesem_f$HU, Qesem_f$Group)

Run the code above in your browser using DataLab