Learn R Programming

diversityArch (version 0.1.0)

Qesem_s: Data used in the examples

Description

Data frame with number of bones of different spicies and diferent levels in Qesem (Israel), and a factor related to the size of the animal. Data source: Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A., (2024)

Usage

data(Qesem_s)

Arguments

Value

Data frame with 15 observations and 7 levels.

Author

Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A.

References

Barat, A. Sansó, A. Arilla-Osuna, M. Blasco, R., Pérez-Fernández, I., Cifuentes-Alcobenda, G. Llorente, R., Vivar-Ríos, D., Assaf, E. Barkai, R., Gopher, A. & Rosell-Ardèvol, J., 2025. Quantifying Diversity through Entropy Decomposition. Insights into Hominin Occupation and Carcass Processing at Qesem cave. Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A., 2024. Exploring the lack of articular ends at the Middle Pleistocene site of Qesem Cave, Israel. Journal of Human Evolution 189, 103509. doi:10.1016/j.jhevol.2024.103509

Examples

Run this code
data(Qesem_s)
names(Qesem_s)
# The following example replicates some of the results of Table 3 in
# Barat, A. Sansó, A. Arilla-Osuna, M. Blasco, R., Pérez-Fernández, I.,
# Cifuentes-Alcobenda, G. Llorente, R., Vivar-Ríos, D., Assaf, E. Barkai, R.,
# Gopher, A. & Rosell-Ardèvol, J., 2025. "Quantifying Diversity through Entropy
# Decomposition. Insights into Hominin Occupation and Carcass Processing at Qesem cave".
all_indices(Qesem_s$HU)

Run the code above in your browser using DataLab