Learn R Programming

diversityArch (version 0.1.0)

all_indices: Diversity indices

Description

Computes and prints all the diversity indices

Usage

all_indices(x, groups = NULL)

Value

No return value. It prints the value of all indicators

Arguments

x

Vector of dimension S (spicies) with the numbers of observed individuals in each spicy. NA values are allowed. 0 values are converted to NA.

groups

Vector of dimension S of factors indicating the groups.

References

"Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"

See Also

shannon, dec_shannon, dominance, equitability, evenness, margalev, menhinick, simpson_D, simpson_E

Examples

Run this code
data(Qesem_s)
all_indices(Qesem_s$HU)
all_indices(Qesem_s$HU, Qesem_s$Group)

Run the code above in your browser using DataLab