Learn R Programming

diversityArch (version 0.1.0)

dec_shannon: Shannon diversity decomposition

Description

Computes Shannon diversity and its decomposition

Usage

dec_shannon(x, groups)

Value

  • shannon: Shannon's total Entropy.

  • within: Within groups entropy.

  • between: Between groups entropy.

  • groups: A data frame with information about each group: relative frequency, internal entropy and number of spicies.

Arguments

x

Vector of dimension S (spicies) with the numbers of observed individuals in each spicy. NA values are allowed. 0 values are converted to NA.

groups

Vector of dimension S of factors indicating the groups.

References

"Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2025): Quantifying Diversity through Entropy Decomposition. Insights into Hominin Occupation and Carcass Processing at Qesem cave"

See Also

shannon

Examples

Run this code
data(Qesem_s)
dec_shannon(Qesem_s$HU, Qesem_s$Group)

Run the code above in your browser using DataLab