Learn R Programming

diversityArch (version 0.1.0)

menhinick: Menhinick index

Description

Computes menhinick's index

Usage

menhinick(x)

Value

Menhinick index.

Arguments

x

Vector of dimension S (spicies) with the numbers of observed individuals in each spicy. NA values are allowed. 0 values are converted to NA.

References

"Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2025): Quantifying Diversity through Entropy Decomposition. Insights into Hominin Occupation and Carcass Processing at Qesem cave"

Examples

Run this code
data(Qesem_s)
menhinick(Qesem_s$HU)

Run the code above in your browser using DataLab