data(Qesem_s)
names(Qesem_s)
# The following example replicates some of the results of Table 3 in
# Barat, A. Sansó, A. Arilla-Osuna, M. Blasco, R., Pérez-Fernández, I.,
# Cifuentes-Alcobenda, G. Llorente, R., Vivar-Ríos, D., Assaf, E. Barkai, R.,
# Gopher, A. & Rosell-Ardèvol, J., 2025. "Quantifying Diversity through Entropy
# Decomposition. Insights into Hominin Occupation and Carcass Processing at Qesem cave".
all_indices(Qesem_s$HU)
Run the code above in your browser using DataLab