powered by
Computes and prints all the diversity indices
all_indices(x, groups = NULL)
No return value. It prints the value of all indicators
Vector of dimension S (spicies) with the numbers of observed individuals in each spicy. NA values are allowed. 0 values are converted to NA.
Vector of dimension S of factors indicating the groups.
"Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
shannon, dec_shannon, dominance, equitability, evenness, margalev, menhinick, simpson_D, simpson_E
data(Qesem_s) all_indices(Qesem_s$HU) all_indices(Qesem_s$HU, Qesem_s$Group)
Run the code above in your browser using DataLab